<!doctype html><html lang="en"><head><meta charset="UTF-8"><meta name="viewport" content="width=device-width,initial-scale=1,maximum-scale=1,user-scalable=0"><title>Focalboard</title><script>window.baseURL = '{{.BaseURL}}'</script><link rel="icon" href="{{.BaseURL}}/static/favicon.svg?v=1"/><script defer="defer" src="{{.BaseURL}}/static/main.js?53a7f672847aa8856f8f"></script></head><body class="focalboard-body"><div id="focalboard-app"></div><div id="focalboard-root-portal"></div></body></html>